namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type VG::name_get() const
{
   const char * __return_value =  ::efl_vg_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::efl_vg_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits<void>::type VG::origin_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::efl_vg_origin_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type VG::origin_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::efl_vg_origin_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits< ::efl::VG>::type VG::mask_get() const
{
    ::Efl_VG* __return_value =  ::efl_vg_mask_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::VG>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::mask_set( ::efl::eolian::in_traits< ::efl::VG>::type m) const
{
    ::efl_vg_mask_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG*,  ::efl::eolian::in_traits< ::efl::VG>::type>(m));
}
inline ::efl::eolian::return_traits<void>::type VG::bounds_get( ::efl::eolian::out_traits<Eina_Rectangle>::type r) const
{
   Eina_Rectangle __out_param_r = {};
    ::efl_vg_bounds_get(this->_eo_ptr()
      , & __out_param_r);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(r, __out_param_r);
}
inline ::efl::eolian::return_traits<bool>::type VG::interpolate( ::efl::eolian::in_traits< ::efl::VG>::type from,  ::efl::eolian::in_traits< ::efl::VG>::type to,  ::efl::eolian::in_traits<double>::type pos_map) const
{
   Eina_Bool __return_value =  ::efl_vg_interpolate(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(from)
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(to)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(pos_map));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::dup( ::efl::eolian::in_traits< ::efl::VG>::type from) const
{
    ::efl_vg_dup(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(from));
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type VG::name_get() const
{
   const char * __return_value =  ::efl_vg_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::efl_vg_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits<void>::type VG::origin_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::efl_vg_origin_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type VG::origin_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::efl_vg_origin_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits< ::efl::VG>::type VG::mask_get() const
{
    ::Efl_VG* __return_value =  ::efl_vg_mask_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::VG>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::mask_set( ::efl::eolian::in_traits< ::efl::VG>::type m) const
{
    ::efl_vg_mask_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG*,  ::efl::eolian::in_traits< ::efl::VG>::type>(m));
}
inline ::efl::eolian::return_traits<void>::type VG::bounds_get( ::efl::eolian::out_traits<Eina_Rectangle>::type r) const
{
   Eina_Rectangle __out_param_r = {};
    ::efl_vg_bounds_get(this->_eo_ptr()
      , & __out_param_r);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(r, __out_param_r);
}
inline ::efl::eolian::return_traits<bool>::type VG::interpolate( ::efl::eolian::in_traits< ::efl::VG>::type from,  ::efl::eolian::in_traits< ::efl::VG>::type to,  ::efl::eolian::in_traits<double>::type pos_map) const
{
   Eina_Bool __return_value =  ::efl_vg_interpolate(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(from)
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(to)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(pos_map));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type VG::dup( ::efl::eolian::in_traits< ::efl::VG>::type from) const
{
    ::efl_vg_dup(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_VG const*,  ::efl::eolian::in_traits< ::efl::VG>::type>(from));
}
inline efl::VG::operator ::efl::VG() const { return *static_cast< ::efl::VG const*>(static_cast<void const*>(this)); }
inline efl::VG::operator ::efl::VG&() { return *static_cast< ::efl::VG*>(static_cast<void*>(this)); }
inline efl::VG::operator ::efl::VG const&() const { return *static_cast< ::efl::VG const*>(static_cast<void const*>(this)); }
} }

